package pl.edu.amu.wmi.socialaggregator.activity

import android.content.Intent
import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import com.jakewharton.rxbinding2.view.RxView
import io.reactivex.disposables.CompositeDisposable
import kotlinx.android.synthetic.main.activity_main.*
import pl.edu.amu.wmi.socialaggregator.R
import pl.edu.amu.wmi.socialaggregator.utils.SocialPlatformsManager
import pl.edu.amu.wmi.socialaggregator.viewholders.PostTextRecycler
import pl.edu.amu.wmi.socialaggregator.viewholders.SocialWithImageRecycler

class MainActivity : AppCompatActivity() {

    private val subs = CompositeDisposable()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        subs.addAll(
            RxView.clicks(createPostButton)
                .subscribe {
                    val intent = Intent(this, NewPostActivity::class.java)
                    startActivity(intent)
                },
            RxView.clicks(connectedSocialsButton)
                .subscribe {
                    val intent = Intent(this, AddSocialActivity::class.java)
                    startActivity(intent)
                }
        )

    }

    override fun onResume() {
        super.onResume()

        connectedSocialsRecyclerView.apply {
            layoutManager = LinearLayoutManager(this@MainActivity)
            adapter = SocialWithImageRecycler(SocialPlatformsManager.getLoggedIn(this@MainActivity),
                R.drawable.ic_launcher_background) {}
        }

        previousPostsRecyclerView.apply {
            layoutManager = LinearLayoutManager(this@MainActivity)
            adapter = PostTextRecycler(SocialPlatformsManager.getLoggedIn(this@MainActivity)
                .map { it to it.getPosts(this@MainActivity).size })
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        subs.clear()
    }
}
